==> qtjambi-qt3drender-6.5.1-sources.jar: io/qt/qt3d/render/QFrameGraphNode.java <==
package io.qt.qt3d.render;

import io.qt.*;


/**
 * <p>Base class of all FrameGraph configuration nodes</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qt3drender-qframegraphnode.html">Qt3DRender::QFrameGraphNode</a></p>
 */
public class QFrameGraphNode extends io.qt.qt3d.core.QNode
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QFrameGraphNode.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QFrameGraphNode(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QFrameGraphNode() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qframegraphnode.html#QFrameGraphNode">Qt3DRender::QFrameGraphNode::QFrameGraphNode(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QFrameGraphNode(io.qt.qt3d.core.@Nullable QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QFrameGraphNode instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qframegraphnode.html#parentFrameGraphNode">Qt3DRender::QFrameGraphNode::parentFrameGraphNode()const</a></p>
     */
    @QtUninvokable
    public final io.qt.qt3d.render.@Nullable QFrameGraphNode parentFrameGraphNode(){
        return parentFrameGraphNode_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.qt3d.render.QFrameGraphNode parentFrameGraphNode_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QFrameGraphNode(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QFrameGraphNode(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QFrameGraphNode instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3drender-6.5.2-sources.jar: io/qt/qt3d/render/QFrameGraphNode.java <==
package io.qt.qt3d.render;

import io.qt.*;


/**
 * <p>Base class of all FrameGraph configuration nodes</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qt3drender-qframegraphnode.html">Qt3DRender::QFrameGraphNode</a></code></p>
 */
public class QFrameGraphNode extends io.qt.qt3d.core.QNode
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QFrameGraphNode.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QFrameGraphNode(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QFrameGraphNode() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qframegraphnode.html#QFrameGraphNode">Qt3DRender::QFrameGraphNode::<wbr>QFrameGraphNode(Qt3DCore::QNode*)</a></code></p>
     */
    @SuppressWarnings({"exports"})
    public QFrameGraphNode(io.qt.qt3d.core.@Nullable QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QFrameGraphNode instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qframegraphnode.html#parentFrameGraphNode">Qt3DRender::QFrameGraphNode::<wbr>parentFrameGraphNode()const</a></code></p>
     */
    @QtUninvokable
    public final io.qt.qt3d.render.@Nullable QFrameGraphNode parentFrameGraphNode(){
        return parentFrameGraphNode_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.qt3d.render.QFrameGraphNode parentFrameGraphNode_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QFrameGraphNode(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * @hidden
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QFrameGraphNode(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QFrameGraphNode instance, QDeclarativeConstructor constructor);
    
}
